/*

Global banks and synthetic funding: the benefits of foreign relatives

MS21-250 - Journal of Money, Credit and Banking

Authors: Fernando Eguren-Martin, Matias Ossandon Busch, and Dennis Reinhard

Baseline regressions

*/ 

* Main FOLDER banking data
global dta_banks "FOLDER\Work Files"

/*

Table 1: Descriptive statistics and difference in means
	
*/ 

*Load data
	cd "$dta_banks" 
	use REG_T27_02v2.dta, clear
	xtset IDBCM date
	sort IDBCM date	
	set more off 
	
*Generate average exposure measure over sample period
	global explist "zExp_bt1"
	local exp $explist
	foreach var of local exp{
	bys IDBM: egen amean`var'=mean(`var') if date>=quarterly("2003q1", "YQ")  & date<=quarterly("2007q1", "YQ") 	
	bys IDBM: egen mean`var'=max(amean`var') 
	}
	
*Generate sample splits by median of exposure distribution 
	local exp $explist
	foreach var of local exp{
	egen bmed`var'=median(mean`var')
	gen d1`var'=0
	replace d1`var'=1 if mean`var'>bmed`var'
	}
	
*Merge FX funding dummies 
	merge m:1 IDB currency date using intcapCC2.dta
	drop _merge 
	sum dp2*		
	xtset IDBCM date
	sort IDBCM date	
	set more off 	
	
* Generate currency-specific RSF
	gen zExp_bt1_usd=.
	replace zExp_bt1_usd=zExp_bt1 if curr=="usd"
	gen zExp_bt1_eur=.
	replace zExp_bt1_eur=zExp_bt1 if curr=="eur"

*Generate descriptives table
	
preserve

*Adjust variables   
	*replace rcap_d2=. if rcap_d2<=0
	
*Keep the effective sample
	keep if IDsample==1	
	
*Rename vars
	rename Dclaims1 var1
	rename zExp_bt1 var2
	rename ltasset_d1 var3
	rename rdepa var4
	rename rliq_d1 var5
	rename rcap_d2 var6
	rename Dclaims1_nk_m1 var7
	rename cb3m var8
	rename adcb_3m var9
	rename foreign var10 
	rename branch var11
	rename rCStliab4 var12
	rename rCSnicm var13
	rename rCSintliab4_cl var14
	rename dp2rCStliab4 var15
	rename dp2rCSnicm var16
	rename dp2rCSintliab4_cl var17
	rename zExp_bt1_usd var18
	rename zExp_bt1_eur var19
	
*Compute descriptives
	foreach var of varlist var1 var2 var3 var4 var5 var6 var7 var8 var9 var10 var11 var12 var13 var14 var15 var16 var17 var18 var19{
	egen ob`var'=count(`var') 
	egen av`var'=mean(`var') 
	egen med`var'=median(`var') 
	egen sd`var'=sd(`var') 
	egen min`var'=min(`var') 
	egen max`var'=max(`var') 
	} 
	
*Difference in means for all variables excepting internal capital markets 
	gen t1=d1zExp_bt1
	foreach var of varlist var1 var2 var3 var4 var5 var6 var7 var10 var11 var12 var13 var18 var19{
	egen auxt1`var'=mean(`var') if t1==1 & date<=quarterly("2008q1", "YQ")
	egen avt1`var'=max(auxt1`var') 
	egen auxt0`var'=mean(`var') if t1==0 & date<=quarterly("2008q1", "YQ")
	egen avt0`var'=max(auxt0`var') 
	drop auxt0`var' auxt1`var' 
	egen auxt1`var'=sd(`var') if t1==1 & date<=quarterly("2008q1", "YQ")
	egen sdt1`var'=max(auxt1`var')
	egen auxt0`var'=sd(`var') if t1==0 & date<=quarterly("2008q1", "YQ")
	egen sdt0`var'=max(auxt0`var') 
	drop auxt0`var' auxt1`var'
	}
	
*Difference in means for internal capital markets variables
	foreach var of varlist var14 var15 var16 var17{
	egen auxt1`var'=mean(`var') if t1==1 
	egen avt1`var'=max(auxt1`var') 
	egen auxt0`var'=mean(`var') if t1==0 
	egen avt0`var'=max(auxt0`var') 
	drop auxt0`var' auxt1`var' 
	egen auxt1`var'=sd(`var') if t1==1 
	egen sdt1`var'=max(auxt1`var')
	egen auxt0`var'=sd(`var') if t1==0 
	egen sdt0`var'=max(auxt0`var') 
	drop auxt0`var' auxt1`var'
	}
	 
	foreach var of varlist var1 var2 var3 var4 var5 var6 var7 var10 var11 var12 var13 var14 var15 var16 var17 var18 var19{
	gen dif`var'=avt1`var'-avt0`var'
	gen imb`var'=dif`var'/sqrt(sdt1`var'^2+sdt0`var'^2)
	}

*Generate Table // imbvar>|0.25| means statistically sign. difference 
	keep obvar1-imbvar19
	keep if _n==1
	gen aux=1
	reshape long obvar avvar medvar sdvar minvar maxvar avt1var avt0var sdt1var sdt0var difvar imbvar, i(aux) j(variable)
	drop aux
	drop sdt1var sdt0var
	drop t1

*Export
	export excel using bdescript.xls, firstrow(variables) replace

	restore	

//******************** END OF TABLE ***********************//	


/*

Table 2: Benchmark results
	
*/ 

*Load data and set panel structure 
	cd "$dta_banks" 
	use REG_T27_02v2.dta, clear
	xtset IDBCM date
	sort IDBCM date	
	set more off 
	
	*Column I: Plain CIP
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		
		preserve
		keep if date>=quarterly("2003q1", "YQ") 
		reghdfe `cred' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' if IDsample==1 ///
		, absorb(constant) 
		
		test L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'=0
		g Test_Fc = r(F)
		g Test_Pc = r(p)
		lincom L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'
		g Test_Cc = r(estimate)
		g Test_SDc = r(se)
		
		outreg2 using results_bkt.xls, keep(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat(ARsq, e(r2_a), Int Coef., sum(Test_Cc), Int SD, sum(Test_SDc), CIP Coef., sum(Test_Cc), CIP SD, sum(Test_SDc), Int P-value, sum(Test_Pc), CIP P-value, sum(Test_Pc)) /// 
		addtext(Credit, `cred', Exposure, `exp', CIP, `cip')  ///
		sortvar(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa') replace	 
		 
		restore  
	
	*Column II: No Control or FE
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		
		preserve
		keep if date>=quarterly("2003q1", "YQ") 
		reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
		L5.c.`exp'#L2.c.`cip' ///
		L5.c.`exp'#L3.c.`cip' ///
		L5.c.`exp'#L4.c.`cip' L5.c.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
		if IDsample==1, absorb(constant) cluster(IDB date)
			
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_C = r(estimate)
		g Test_SD = r(se)
		
		test L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'=0
		g Test_Fc = r(F)
		g Test_Pc = r(p)
		lincom L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'
		g Test_Cc = r(estimate)
		g Test_SDc = r(se)
		
		outreg2 using results_bkt.xls, keep(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat(ARsq, e(r2_a), Int Coef., sum(Test_C), Int SD, sum(Test_SD), CIP Coef., sum(Test_Cc), CIP SD, sum(Test_SDc), Int P-value, sum(Test_P), CIP P-value, sum(Test_Pc)) /// 
		addtext(Credit, `cred', Exposure, `exp', CIP, `cip')  ///
		sortvar(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa') 	 
		 
		restore  
	
	*Column III: Add Controls 
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		
		preserve
		keep if date>=quarterly("2003q1", "YQ") 
		reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
		L5.c.`exp'#L2.c.`cip' ///
		L5.c.`exp'#L3.c.`cip' ///
		L5.c.`exp'#L4.c.`cip' L5.c.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1 if IDsample==1, absorb(constant) cluster(IDB date)
			
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_C = r(estimate)
		g Test_SD = r(se)
		
		test L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'=0
		g Test_Fc = r(F)
		g Test_Pc = r(p)
		lincom L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'
		g Test_Cc = r(estimate)
		g Test_SDc = r(se)
		
		outreg2 using results_bkt.xls, keep(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat(ARsq, e(r2_a), Int Coef., sum(Test_C), Int SD, sum(Test_SD), CIP Coef., sum(Test_Cc), CIP SD, sum(Test_SDc), Int P-value, sum(Test_P), CIP P-value, sum(Test_Pc)) /// 
		addtext(Credit, `cred', Exposure, `exp', CIP, `cip')  ///
		sortvar(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa') 	 
		 
		restore  
	
	*Column IV: Add bank and country-quarter FE
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		
		preserve
		keep if date>=quarterly("2003q1", "YQ") 
		reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
		L5.c.`exp'#L2.c.`cip' ///
		L5.c.`exp'#L3.c.`cip' ///
		L5.c.`exp'#L4.c.`cip' L5.c.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1 if IDsample==1, absorb(IDB IDC#date) cluster(IDB date)
			
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_C = r(estimate)
		g Test_SD = r(se)
		
		test L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'=0
		g Test_Fc = r(F)
		g Test_Pc = r(p)
		lincom L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'
		g Test_Cc = r(estimate)
		g Test_SDc = r(se)
		
		outreg2 using results_bkt.xls, keep(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat(ARsq, e(r2_a), Int Coef., sum(Test_C), Int SD, sum(Test_SD), CIP Coef., sum(Test_Cc), CIP SD, sum(Test_SDc), Int P-value, sum(Test_P), CIP P-value, sum(Test_Pc)) /// 
		addtext(Credit, `cred', Exposure, `exp', CIP, `cip')  ///
		sortvar(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa') 	 
		 
		restore  
	
	*Column V: Full FE 
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		
		preserve
		keep if date>=quarterly("2003q1", "YQ") 
		reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
		L5.c.`exp'#L2.c.`cip' ///
		L5.c.`exp'#L3.c.`cip' ///
		L5.c.`exp'#L4.c.`cip' L5.c.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1 if IDsample==1, absorb(IDBCM IDCM#date) cluster(IDB date)
			
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_C = r(estimate)
		g Test_SD = r(se)
		
		test L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'=0
		g Test_Fc = r(F)
		g Test_Pc = r(p)
		lincom L1.c.`cip'+L2.c.`cip'+L3.c.`cip'+L4.c.`cip'
		g Test_Cc = r(estimate)
		g Test_SDc = r(se)
		
		outreg2 using results_bkt.xls, keep(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat(ARsq, e(r2_a), Int Coef., sum(Test_C), Int SD, sum(Test_SD), CIP Coef., sum(Test_Cc), CIP SD, sum(Test_SDc), Int P-value, sum(Test_P), CIP P-value, sum(Test_Pc)) /// 
		addtext(Credit, `cred', Exposure, `exp', CIP, `cip')  ///
		sortvar(L5.`exp' cL5.`exp'#cL.`cip' cL5.`exp'#cL2.`cip' cL5.`exp'#cL3.`cip' cL5.`exp'#cL4.`cip' L.`cip' L2.`cip' L3.`cip' L4.`cip' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa') 	 
		 
		restore  	
		
//******************** END OF TABLE ***********************//	

	
/*

Table 3: Access to FX funding: Foreign Branches
	
*/ 		
	
*Load data and set panel structure 
	cd "$dta_banks" 
	use REG_T27_02v2.dta, clear
	xtset IDBCM date
	sort IDBCM date	
	set more off 	
	
*Column I: Copied from Table 2 (Column V)
		
*Column II: Overall branches
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		local triple pax
			
		preserve
		rename branch pax
		keep if date>=quarterly("2003q1", "YQ") 
		reghdfe `cred' /// 
		L5.c.`exp'#L1.c.`cip'#L5.1.`triple' L5.c.`exp'#L2.c.`cip'#L5.1.`triple' L5.c.`exp'#L3.c.`cip'#L5.1.`triple' L5.c.`exp'#L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' L5.c.`exp'#L4.c.`cip' ///
		L1.c.`cip'#L5.1.`triple' L2.c.`cip'#L5.1.`triple' L3.c.`cip'#L5.1.`triple' L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L5.1.`triple' L5.`exp' L1.`cip' L2.`cip' L3.`cip' L4.`cip' L5.`triple' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1, absorb(IDBCM IDCM#date) cluster(IDB date)
					
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_Fb = r(F)
		g Test_Pb = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_Cb = r(estimate)
		g Test_SDb = r(se)
				
		test L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'=0
		g Test_Ff = r(F)
		g Test_Pf = r(p)
		lincom L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'
		g Test_Cf = r(estimate)
		g Test_SDf = r(se)
		
		test L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'
		g Test_C = r(estimate)
		g Test_SD = r(se)
			
		outreg2 using results_fragAb.xls, keep(L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat( ///
		Triple Coef., sum(Test_C), Triple SD, sum(Test_SD), Triple P-value, sum(Test_P), ///
		Double Coef., sum(Test_Cb), Double SD, sum(Test_SDb), Double P-value, sum(Test_Pb), ///
		TriplexCIP Coef., sum(Test_Cf), TriplexCIP SD, sum(Test_SDf), TriplexCIP P-value, sum(Test_Pf)) ///
		sortvar(L5.`triple' L5.`exp' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa') replace  		 
		
		egen Nbank=group(bank) if e(sample)==1
		egen Nmkt=group(country currency) if e(sample)==1
		sum Nbank Nmkt
		
		restore	 		 	
	
*Column III: Branches from CA
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		local triple pax
			
		preserve
		rename CAbrancht pax
		keep if date>=quarterly("2003q1", "YQ") 
		reghdfe `cred' /// 
		L5.c.`exp'#L1.c.`cip'#L5.1.`triple' L5.c.`exp'#L2.c.`cip'#L5.1.`triple' L5.c.`exp'#L3.c.`cip'#L5.1.`triple' L5.c.`exp'#L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' L5.c.`exp'#L4.c.`cip' ///
		L1.c.`cip'#L5.1.`triple' L2.c.`cip'#L5.1.`triple' L3.c.`cip'#L5.1.`triple' L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L5.1.`triple' L5.`exp' L1.`cip' L2.`cip' L3.`cip' L4.`cip' L5.`triple' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1, absorb(IDBCM IDCM#date) cluster(IDB date)
					
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_Fb = r(F)
		g Test_Pb = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_Cb = r(estimate)
		g Test_SDb = r(se)
				
		test L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'=0
		g Test_Ff = r(F)
		g Test_Pf = r(p)
		lincom L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'
		g Test_Cf = r(estimate)
		g Test_SDf = r(se)
		
		test L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'
		g Test_C = r(estimate)
		g Test_SD = r(se)
			
		outreg2 using results_fragAb.xls, keep(L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat( ///
		Triple Coef., sum(Test_C), Triple SD, sum(Test_SD), Triple P-value, sum(Test_P), ///
		Double Coef., sum(Test_Cb), Double SD, sum(Test_SDb), Double P-value, sum(Test_Pb), ///
		TriplexCIP Coef., sum(Test_Cf), TriplexCIP SD, sum(Test_SDf), TriplexCIP P-value, sum(Test_Pf)) ///
		sortvar(L5.`triple' L5.`exp' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa')   		 
		
		egen Nbank=group(bank) if e(sample)==1
		egen Nmkt=group(country currency) if e(sample)==1
		sum Nbank Nmkt
		
		restore	 		 
		
*Column IV: Branches from non-CA
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		local triple pax
			
		preserve
		rename NCAbrancht pax
		keep if date>=quarterly("2003q1", "YQ") 
		reghdfe `cred' /// 
		L5.c.`exp'#L1.c.`cip'#L5.1.`triple' L5.c.`exp'#L2.c.`cip'#L5.1.`triple' L5.c.`exp'#L3.c.`cip'#L5.1.`triple' L5.c.`exp'#L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' L5.c.`exp'#L4.c.`cip' ///
		L1.c.`cip'#L5.1.`triple' L2.c.`cip'#L5.1.`triple' L3.c.`cip'#L5.1.`triple' L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L5.1.`triple' L5.`exp' L1.`cip' L2.`cip' L3.`cip' L4.`cip' L5.`triple' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1, absorb(IDBCM IDCM#date) cluster(IDB date)
					
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_Fb = r(F)
		g Test_Pb = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_Cb = r(estimate)
		g Test_SDb = r(se)
				
		test L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'=0
		g Test_Ff = r(F)
		g Test_Pf = r(p)
		lincom L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'
		g Test_Cf = r(estimate)
		g Test_SDf = r(se)
		
		test L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'
		g Test_C = r(estimate)
		g Test_SD = r(se)
			
		outreg2 using results_fragAb.xls, keep(L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat( ///
		Triple Coef., sum(Test_C), Triple SD, sum(Test_SD), Triple P-value, sum(Test_P), ///
		Double Coef., sum(Test_Cb), Double SD, sum(Test_SDb), Double P-value, sum(Test_Pb), ///
		TriplexCIP Coef., sum(Test_Cf), TriplexCIP SD, sum(Test_SDf), TriplexCIP P-value, sum(Test_Pf)) ///
		sortvar(L5.`triple' L5.`exp' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa')   		 
		
		egen Nbank=group(bank) if e(sample)==1
		egen Nmkt=group(country currency) if e(sample)==1
		sum Nbank Nmkt
		
		restore	 		 		
	
//******************** END OF TABLE ***********************//	
	
/*

Table 4: Access to FX funding: on-balance-sheet FX-funding
	
*/ 		
		
*Load data and set panel structure 
		cd "$dta_banks" 
		use REG_T27_02v2.dta, clear
		xtset IDBCM date
		sort IDBCM date	
		set more off 
		
*Set negative values to 0
		replace rCSfnicm=0 if rCSfnicm<0
		replace rCSnicm=0 if rCSnicm<0
		replace rfvnicm=0 if rfvnicm<0

*Create dummy at the 75ptile for ratios 
		preserve 
		collapse (mean) rCSfnicm rCSnicm rfvnicm rCStliab4 rCStliab5 rnCSrliab1_cl rnCSrliab2_cl rCSintliab4_cl rCSintliab5_cl rCStliab1_ca rCStliab2_ca rCStliab3_ca rCSintliab3_ca rCSintliab3_cl rnCSrliab1_bt rnCSrliab2_bt rukliab rukCSliab1 rukCSliab2 rukfx1 rukfx2 rukfx3 rukfx4 rnrliab_cl rnrliab_bt rdepnr_ag rCSbyk1_ca rCSbyk2_ca rintliab_ca rCSintliab1_ca rCSintliab2_ca rintliab_cl rCSintliab1_cl rCSintliab2_cl, by(IDB currency date) 
		foreach var of varlist rCSfnicm rCSnicm rfvnicm rCStliab4 rCStliab5 rnCSrliab1_cl rnCSrliab2_cl rCSintliab4_cl rCSintliab5_cl rCStliab1_ca rCStliab2_ca rCStliab3_ca rCSintliab3_ca rCSintliab3_cl rnCSrliab1_bt rnCSrliab2_bt rukliab rukCSliab1 rukCSliab2 rukfx1 rukfx2 rukfx3 rukfx4 rnrliab_cl rnrliab_bt rdepnr_ag rCSbyk1_ca rCSbyk2_ca rintliab_ca rCSintliab1_ca rCSintliab2_ca rintliab_cl rCSintliab1_cl rCSintliab2_cl{
		bys currency date: egen p`var'=pctile(`var'), p(75)
		gen dp2`var'=0 
		replace dp2`var'=1 if `var'>p`var'
		drop p`var'
		}
		save intcapCC2.dta, replace
		restore 
		
		merge m:1 IDB currency date using intcapCC2.dta
		drop _merge 
		sum dp2*		
		xtset IDBCM date
		sort IDBCM date	
		set more off 	

*Column I: Copied from Table 2 (Column V)
		
*Column II: Triple interaction with total FX funding 
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		local triple pax
			
		preserve
		rename dp2rCStliab4 pax
		keep if date>=quarterly("2008q1", "YQ") 
		reghdfe `cred' /// 
		L5.c.`exp'#L1.c.`cip'#L5.1.`triple' L5.c.`exp'#L2.c.`cip'#L5.1.`triple' L5.c.`exp'#L3.c.`cip'#L5.1.`triple' L5.c.`exp'#L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' L5.c.`exp'#L4.c.`cip' ///
		L1.c.`cip'#L5.1.`triple' L2.c.`cip'#L5.1.`triple' L3.c.`cip'#L5.1.`triple' L4.c.`cip'#L5.1.`triple' ///
		L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1, absorb(IDBCM IDCM#date) cluster(IDB date)
					
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_Fb = r(F)
		g Test_Pb = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_Cb = r(estimate)
		g Test_SDb = r(se)
				
		test L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'=0
		g Test_Ff = r(F)
		g Test_Pf = r(p)
		lincom L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'
		g Test_Cf = r(estimate)
		g Test_SDf = r(se)
		
		test L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'
		g Test_C = r(estimate)
		g Test_SD = r(se)
		
		outreg2 using results_fragB.xls, keep(L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat( ///
		Triple Coef., sum(Test_C), Triple SD, sum(Test_SD), Triple P-value, sum(Test_P), ///
		Double Coef., sum(Test_Cb), Double SD, sum(Test_SDb), Double P-value, sum(Test_Pb), ///
		TriplexCIP Coef., sum(Test_Cf), TriplexCIP SD, sum(Test_SDf), TriplexCIP P-value, sum(Test_Pf)) ///
		sortvar(L5.`triple' L5.`exp' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa') replace   		 		
		
		restore	  	

*Column III: Triple interaction with ICM ratio
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		local triple pax
			
		preserve
		rename dp2rCSintliab4_cl pax 
		keep if date>=quarterly("2008q1", "YQ") //works best 2008q1
		reghdfe `cred' /// 
		L5.c.`exp'#L1.c.`cip'#L5.1.`triple' L5.c.`exp'#L2.c.`cip'#L5.1.`triple' L5.c.`exp'#L3.c.`cip'#L5.1.`triple' L5.c.`exp'#L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' L5.c.`exp'#L4.c.`cip' ///
		L1.c.`cip'#L5.1.`triple' L2.c.`cip'#L5.1.`triple' L3.c.`cip'#L5.1.`triple' L4.c.`cip'#L5.1.`triple' ///
		L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1, absorb(IDBCM IDCM#date) cluster(IDB date)
					
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_Fb = r(F)
		g Test_Pb = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_Cb = r(estimate)
		g Test_SDb = r(se)
				
		test L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'=0
		g Test_Ff = r(F)
		g Test_Pf = r(p)
		lincom L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'
		g Test_Cf = r(estimate)
		g Test_SDf = r(se)
		
		test L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'
		g Test_C = r(estimate)
		g Test_SD = r(se)

		outreg2 using results_fragB.xls, keep(L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat( ///
		Triple Coef., sum(Test_C), Triple SD, sum(Test_SD), Triple P-value, sum(Test_P), ///
		Double Coef., sum(Test_Cb), Double SD, sum(Test_SDb), Double P-value, sum(Test_Pb), ///
		TriplexCIP Coef., sum(Test_Cf), TriplexCIP SD, sum(Test_SDf), TriplexCIP P-value, sum(Test_Pf)) ///
		sortvar(L5.`triple' L5.`exp' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa')    		 		
		
		restore 
		
*Column IV: Triple interaction with non-ICM ratio 
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		local triple pax
			
		preserve
		rename dp2rCSnicm pax
		keep if date>=quarterly("2007q4", "YQ") 
		reghdfe `cred' /// 
		L5.c.`exp'#L1.c.`cip'#L5.1.`triple' L5.c.`exp'#L2.c.`cip'#L5.1.`triple' L5.c.`exp'#L3.c.`cip'#L5.1.`triple' L5.c.`exp'#L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' L5.c.`exp'#L4.c.`cip' ///
		L1.c.`cip'#L5.1.`triple' L2.c.`cip'#L5.1.`triple' L3.c.`cip'#L5.1.`triple' L4.c.`cip'#L5.1.`triple' ///
		L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1, absorb(IDBCM IDCM#date) cluster(IDB date)
					
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_Fb = r(F)
		g Test_Pb = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_Cb = r(estimate)
		g Test_SDb = r(se)
				
		test L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'=0
		g Test_Ff = r(F)
		g Test_Pf = r(p)
		lincom L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'
		g Test_Cf = r(estimate)
		g Test_SDf = r(se)
		
		test L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'
		g Test_C = r(estimate)
		g Test_SD = r(se)
		
		outreg2 using results_fragB.xls, keep(L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat( ///
		Triple Coef., sum(Test_C), Triple SD, sum(Test_SD), Triple P-value, sum(Test_P), ///
		Double Coef., sum(Test_Cb), Double SD, sum(Test_SDb), Double P-value, sum(Test_Pb), ///
		TriplexCIP Coef., sum(Test_Cf), TriplexCIP SD, sum(Test_SDf), TriplexCIP P-value, sum(Test_Pf)) ///
		sortvar(L5.`triple' L5.`exp' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa')    		 		
		restore 	
				
*Column V: Triple interaction with ICM ratio: Foreign banks
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		local triple pax
			
		preserve
		rename dp2rCSintliab4_cl pax
		keep if foreign==1
		keep if date>=quarterly("2008q1", "YQ") 
		reghdfe `cred' /// 
		L5.c.`exp'#L1.c.`cip'#L5.1.`triple' L5.c.`exp'#L2.c.`cip'#L5.1.`triple' L5.c.`exp'#L3.c.`cip'#L5.1.`triple' L5.c.`exp'#L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' L5.c.`exp'#L4.c.`cip' ///
		L1.c.`cip'#L5.1.`triple' L2.c.`cip'#L5.1.`triple' L3.c.`cip'#L5.1.`triple' L4.c.`cip'#L5.1.`triple' ///
		L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1, absorb(IDBCM IDCM#date) cluster(IDB date)
					
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_Fb = r(F)
		g Test_Pb = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_Cb = r(estimate)
		g Test_SDb = r(se)
				
		test L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'=0
		g Test_Ff = r(F)
		g Test_Pf = r(p)
		lincom L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'
		g Test_Cf = r(estimate)
		g Test_SDf = r(se)
		
		test L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'
		g Test_C = r(estimate)
		g Test_SD = r(se)

		outreg2 using results_fragB.xls, keep(L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat( ///
		Triple Coef., sum(Test_C), Triple SD, sum(Test_SD), Triple P-value, sum(Test_P), ///
		Double Coef., sum(Test_Cb), Double SD, sum(Test_SDb), Double P-value, sum(Test_Pb), ///
		TriplexCIP Coef., sum(Test_Cf), TriplexCIP SD, sum(Test_SDf), TriplexCIP P-value, sum(Test_Pf)) ///
		sortvar(L5.`triple' L5.`exp' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa')    		 		
		restore	
		
*Column VI: Triple interaction with ICM ratio: Domestic banks	
		local cred Dclaims1
		local exp zExp_bt1
		local cip adcb_3m     
		local triple pax
			
		preserve
		rename dp2rCSintliab4_cl pax
		keep if foreign==0
		keep if date>=quarterly("2008q1", "YQ") 
		reghdfe `cred' /// 
		L5.c.`exp'#L1.c.`cip'#L5.1.`triple' L5.c.`exp'#L2.c.`cip'#L5.1.`triple' L5.c.`exp'#L3.c.`cip'#L5.1.`triple' L5.c.`exp'#L4.c.`cip'#L5.1.`triple' ///
		L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' L5.c.`exp'#L4.c.`cip' ///
		L1.c.`cip'#L5.1.`triple' L2.c.`cip'#L5.1.`triple' L3.c.`cip'#L5.1.`triple' L4.c.`cip'#L5.1.`triple' ///
		L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' ///
		L1.(ltasset_d1 rdepa rliq_d1 rcap_d2) `cred'_nk_m1, absorb(IDBCM IDCM#date) cluster(IDB date)
					
		test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
		g Test_Fb = r(F)
		g Test_Pb = r(p)
		lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
		g Test_Cb = r(estimate)
		g Test_SDb = r(se)
				
		test L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'=0
		g Test_Ff = r(F)
		g Test_Pf = r(p)
		lincom L5.1.`triple'#L1.c.`cip'+L5.1.`triple'#L2.c.`cip'+L5.1.`triple'#L3.c.`cip'+L5.1.`triple'#L4.c.`cip'
		g Test_Cf = r(estimate)
		g Test_SDf = r(se)
		
		test L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'=0
		g Test_F = r(F)
		g Test_P = r(p)
		lincom L5.c.`exp'#L1.c.`cip'#L5.1.`triple'+L5.c.`exp'#L2.c.`cip'#L5.1.`triple'+L5.c.`exp'#L3.c.`cip'#L5.1.`triple'+L5.c.`exp'#L4.c.`cip'#L5.1.`triple'
		g Test_C = r(estimate)
		g Test_SD = r(se)

		outreg2 using results_fragB.xls, keep(L5.`exp' L5.`triple' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ///
		dec(3) addstat( ///
		Triple Coef., sum(Test_C), Triple SD, sum(Test_SD), Triple P-value, sum(Test_P), ///
		Double Coef., sum(Test_Cb), Double SD, sum(Test_SDb), Double P-value, sum(Test_Pb), ///
		TriplexCIP Coef., sum(Test_Cf), TriplexCIP SD, sum(Test_SDf), TriplexCIP P-value, sum(Test_Pf)) ///
		sortvar(L5.`triple' L5.`exp' L5.c.`exp'#L5.1.`triple' L1.ltasset_d1 L1.rdepa L1.rliq_d1 L1.rcap_d2 `cred'_nk_m1) ctitle(`expa')    		 		
		restore 		
		
//******************** END OF TABLE ***********************//	

		
//******************** END OF DOFILE ***********************//	
		
		



