/*

Global banks and synthetic funding: the benefits of foreign relatives

MS21-250 - Journal of Money, Credit and Banking

Authors: Fernando Eguren-Martin, Matias Ossandon Busch, and Dennis Reinhard

Country-currency level regressions

*/ 

	
* Main folder banking data
global dta_banks "FOLDER\Work Files"

*Set directory
cd "$dta_banks"

/*

Load CC-CL data and create panel including all active banks

*/ 

*Load bank data
	use UK_BankingFlows_CCCL_mob_2.0.dta, clear 

*Merge alternative country code with 3-digits
	merge m:1 countrycode2_vis using countrycodes.dta
	drop if _merge==2
	drop _merge

*Set time window
	keep if date>=quarterly("2002q1", "YQ") 

*Generate country variable
	gen country=countrycode2_vis

*Adjust bank name fo "Shinhan Bank" 
	replace bankname="SHINHAN BANK 2" if bank==8645

*Generate bank-country ID 
	sort bankname country date
	egen IDBC=group(bankname country)
	sum IDBC
	drop if IDBC==. 

*Count bank and countries 
	drop IDBC
	egen IDB=group(bankname)
	egen IDC=group(country)
	egen IDBC=group(bankname country)
	sum IDB IDC IDBC 

*Select variable of interest - total credit by country/currency/date // 
	#delimit ;  
	keep bank-quarter 
	CC1xA* CC1xB* CC1xD* CC1xE* CC1xL* CC1xM* 
	CC15xA* CC15xB* CC15xD* CC15xE* CC15xL* CC15xM*
	CL1x* CC1intx* CL1intx*
	country IDBC IDC IDB code_3digit code_2digit
	;
	#delimit cr 

*Add this to adjust name of extra CC variables before reshaping
	local curr A L D E M B
	local sufix bk bk_f fin fin_f nbk nbk_f nfin nfin_f
	foreach var of local curr{
	foreach item of local sufix{
	rename CC1x`var'_`item' CC1`item'x`var'
	}
	}

*Add this to adjust name of CL variables before reshaping
	local curr A L D E M B
	foreach var of local curr{
	rename CC1x`var'_f CC1_fx`var'
	rename CC15x`var'_f CC15_fx`var'
	rename CL1x`var'_f CL1_fx`var'
	}

*Reshape to generate currency variables. Panel is bank-country-currency-date
	reshape long CC1x CC1_fx CC15x CC15_fx CC1bkx CC1nbkx CC1finx CC1nfinx CC1bk_fx CC1nbk_fx CC1fin_fx CC1nfin_fx CL1x CL1_fx CC1intx CL1intx, i(bankname country date) j(currency) string

*Rename variables of interest 
	
	*Total loans per currency
	rename CC1x loan
	rename CC1_fx loan_f

	*Total claims (loans + securities) per currency
	rename CC15x claims
	rename CC15_fx claims_f
	
	*Total liabilities per currency
	rename CL1x tliab
	rename CL1_fx tliab_f
	
	*Total loans to banks + other financial institutions
	rename CC1finx loan_fin
	rename CC1fin_fx loan_fin_f
	
	*Total loans to non-financial agents: government + nonfin firms + household + others
	rename CC1nfinx loan_nfin
	rename CC1nfin_fx loan_nfin_f
	
	*Total loans to banks
	rename CC1bkx loan_bk
	rename CC1bk_fx loan_bk_f
	
	*Total loans to non-banks: variable "other non residents" in CC forms
	rename CC1nbkx loan_nbk
	rename CC1nbk_fx loan_nbk_f
	
	*Total internal claims/liabilities from the respective country
	rename CL1intx liab_int
	rename CC1intx claim_int
	
*Set panel structure	
	order bankname country currency date 
	sort bankname country currency date

*Re-define currency variable
	replace currency="jpy" if currency=="E"
	replace currency="usd" if currency=="B"
	replace currency="eur" if currency=="L"
	replace currency="gbp" if currency=="A"
	replace currency="chf" if currency=="D"
	replace currency="oth" if currency=="M"

*ID variables
	drop IDB IDC IDBC
	egen IDB=group(bankname)
	egen IDC=group(country)
	egen IDBC=group(bankname country)
	egen IDBCM=group(bankname country currency)
	sum IDB IDC IDBC IDBCM

*Drop "small" countries, offshore centers
	local sample_list_small BRSI CANT CAPE COMO DOMA FARO FIJI FPOL FSAT GILB GREN ///
	GUAD MALD MARS MART MAYO MICR NAUR NWCL PALU REUN SATP SEYC SLUC SPMI SVIN TUVA USTP USVI
	foreach var of local sample_list_small {
	drop if country=="`var'"	
	}

*Merge BT forms 
	merge m:1 bank date using Panel_BT_01v2.dta   
	keep if _merge==3
	drop _merge

*Merge non-resident BT vars reshaped with bank-curency structure
	merge m:1 bank currency date using Panel_BT_NRv2.dta 
	drop if bankname=="" //this are banks not reported in final CC sample
	drop _merge

*Save working sample 
	cd "$dta_banks"
	save AGPanel_CCCL_01.dta, replace //this data includes all variables of interest

/*

Compute RSF and auxiliary variables 

*/ 

*Load data with CC and BT variables
	cd "$dta_banks"
	use AGPanel_CCCL_01.dta, clear //this data includes all variables of interest

*Generate identifier per bank/currency
	egen IDBM=group(bankname currency)
	sum IDBM
	
*Rename BT variables
	rename rdeps_ rdeps
	rename rdept_ rdept 
	rename rdepa_ rdepa
	rename rdepnr_ rdepnr	
	rename rdepuk_ rdepuk
	rename rdeprt_ rdeprt
	rename rdepat_ rdepat
	rename rliqCS1_ rliqCS1
	rename rliqCS2_ rliqCS2
	rename rliqCS3_ rliqCS3
	rename rliqCS4_ rliqCS4 
	rename rliqCS5_ rliqCS5
	rename rliqCS6_ rliqCS6
	rename domliab_ domliab

*Compute growth rates
	xtset IDBCM date
	sort IDBCM date
	local Flows claims loan 
	foreach var of local Flows {
	gen D`var'1 = (ln(abs(L.`var')+`var'_f)-ln(abs(L.`var')))
	}
	
	local Flows claims loan loan_fin loan_nfin loan_bk loan_nbk  
	foreach var of local Flows {
	gen D`var'2 = (`var'_f/(abs(L.`var')))
	}
	
	sum Dclaims1 Dclaims2 Dloan1 Dloan2, d
	
*RSF Measure: Exposure from BT forms including all countries but excluding country "j"
	
	*Substract bank-country specific posititons from BT forms
		gen bwaclaims=claimsb_
		gen bwatliab=liabb_
		gen bwaloan=loansb_

		local sufix claims tliab loan
		foreach var of local sufix{
		gen btr`var'=bwa`var'-`var'
		}
		sort bankname country currency date
	
	*Exposures from consolidated BT positions (only EUR, USD, and GBP, otherwise missing)
		gen Exp_bt1=(claimsb_-liabb_)/claimsb_
		gen Exp_bt2=(claimsb_-liabb_)/liabb_
		
	*Exposures from consolidated BT positions (only EUR, USD, and GBP, otherwise missing)
		gen Exp_btr1=(btrclaims-btrtliab)/btrclaims
		gen Exp_btr2=(btrclaims-btrtliab)/btrtliab
		
	*Generate exposure variables equal 0 for negative values
		local expa Exp_bt1 Exp_bt2 Exp_btr1 Exp_btr2
		foreach var of local expa{
		gen z`var'=`var'
		replace z`var'=0 if z`var'<0
		}
		
		sort bankname country currency date	
		
/*
Note: 

The next two blocks of codes compute two alternatives for the 
bank-time level growth rate in "other currencies":

Measure 1: Average growth rate per bank in currencies different than "k". 

Measure 2: Aggregate growth rate per bank in currencies different than "k". 	

Measure 3: Country-level aggregate growth rates in currencies different than "k". 
			
*/ 

	*Measure 1: Average Bank-level growth rate in "other currencies" 
		local sufix Dclaims1 Dloan1 Dclaims2 Dloan2
		foreach var of local sufix{
		bys IDB date: egen a1`var'_gbp=mean(`var') if currency!="gbp" & country!="WORL"
		bys IDB date: egen a1`var'_eur=mean(`var') if currency!="eur" & country!="WORL"
		bys IDB date: egen a1`var'_usd=mean(`var') if currency!="usd" & country!="WORL"
		bys IDB date: egen a1`var'_jpy=mean(`var') if currency!="jpy" & country!="WORL"
		bys IDB date: egen a1`var'_chf=mean(`var') if currency!="chf" & country!="WORL"
		bys IDB date: egen a1`var'_oth=mean(`var') if currency!="oth" & country!="WORL"

		bys IDB date: egen a2`var'_gbp=max(a1`var'_gbp) 
		bys IDB date: egen a2`var'_eur=max(a1`var'_eur) 
		bys IDB date: egen a2`var'_usd=max(a1`var'_usd) 
		bys IDB date: egen a2`var'_jpy=max(a1`var'_jpy) 
		bys IDB date: egen a2`var'_chf=max(a1`var'_chf) 
		bys IDB date: egen a2`var'_oth=max(a1`var'_oth) 
		
		gen `var'_nk_m1=a2`var'_gbp
		replace `var'_nk_m1=a2`var'_eur if currency=="eur"
		replace `var'_nk_m1=a2`var'_usd if currency=="usd"
		replace `var'_nk_m1=a2`var'_jpy if currency=="jpy"
		replace `var'_nk_m1=a2`var'_chf if currency=="chf"
		replace `var'_nk_m1=a2`var'_oth if currency=="oth"
		}
		drop a1* a2*
		sort bankname country currency date
	
	*Measure 2: Aggregate Bank-level growth rate in "other currencies" 
		local sufix loan loan_f claims claims_f
		foreach var of local sufix{
		bys IDB date: egen a1`var'_gbp=sum(`var') if currency=="gbp" & country!="WORL"
		bys IDB date: egen a1`var'_eur=sum(`var') if currency=="eur" & country!="WORL"
		bys IDB date: egen a1`var'_usd=sum(`var') if currency=="usd" & country!="WORL"
		bys IDB date: egen a1`var'_jpy=sum(`var') if currency=="jpy" & country!="WORL"
		bys IDB date: egen a1`var'_chf=sum(`var') if currency=="chf" & country!="WORL"
		bys IDB date: egen a1`var'_oth=sum(`var') if currency=="oth" & country!="WORL"	
		bys IDB date: egen a1`var'_total=sum(`var') if country!="WORL"	
		bys IDB date: egen a2`var'_gbp=max(a1`var'_gbp) 
		bys IDB date: egen a2`var'_eur=max(a1`var'_eur) 
		bys IDB date: egen a2`var'_usd=max(a1`var'_eur) 
		bys IDB date: egen a2`var'_jpy=max(a1`var'_jpy) 
		bys IDB date: egen a2`var'_chf=max(a1`var'_chf) 
		bys IDB date: egen a2`var'_oth=max(a1`var'_oth) 
		bys IDB date: egen a2`var'_total=max(a1`var'_total) 
		}
		sort bankname country currency date	
	
		*Compute total claims in "other currencies" at the bank-world level
			local sufix loan loan_f claims claims_f
			foreach var of local sufix{
			gen a3`var'_gbp=a2`var'_total-a2`var'_gbp 
			gen a3`var'_eur=a2`var'_total-a2`var'_eur
			gen a3`var'_usd=a2`var'_total-a2`var'_usd
			gen a3`var'_jpy=a2`var'_total-a2`var'_jpy
			gen a3`var'_chf=a2`var'_total-a2`var'_chf
			gen a3`var'_oth=a2`var'_total-a2`var'_oth
			
			gen `var'_nk_m2=a3`var'_gbp
			replace `var'_nk_m2=a3`var'_eur if currency=="eur"
			replace `var'_nk_m2=a3`var'_usd if currency=="usd"
			replace `var'_nk_m2=a3`var'_jpy if currency=="jpy"
			replace `var'_nk_m2=a3`var'_chf if currency=="chf"
			replace `var'_nk_m2=a3`var'_oth if currency=="oth"
			}
			
			drop a1* a2* a3*
			
		*Aggregate growth rates for "other currencies" at the bank-world level 
			xtset IDBCM date
			sort IDBCM date
			local Flows claims loan
			foreach var of local Flows {
			gen D`var'1_nk_m2 = (ln(abs(L.`var'_nk_m2)+`var'_f_nk_m2)-ln(abs(L.`var'_nk_m2)))
			}
			
			local Flows claims loan
			foreach var of local Flows {
			gen D`var'2_nk_m2 = (`var'_f_nk_m2/(abs(L.`var'_nk_m2)))
			}

		*Save working sample 
			cd "$dta_banks"
			save AGPanel_CCCL_02.dta, replace
		
	*Measure 3: Total at country-currency level (aggregated)

		*Load data
			use AGPanel_CCCL_02.dta, clear
			
		*Collapse sum of flows and stocks per country-currency
			collapse (sum) claims loan claims_f loan_f, by(country currency date)
		
		*Generate identifiers
			egen IDCM=group(country currency)
		
		*Growth rates as computed from flows
			xtset IDCM date
			sort IDCM date
			local Flows claims loan
			foreach var of local Flows {
			gen DA`var'1 = (ln(abs(L.`var')+`var'_f)-ln(abs(L.`var')))
			}
			
			local Flows claims loan
			foreach var of local Flows {
			gen DA`var'2 = (`var'_f/(abs(L.`var')))
			}
			
		*Measure 1: Average growth rate in other currencies to all countries 
			local sufix DAclaims1 DAloan1 DAclaims2 DAloan2
			foreach var of local sufix{
			bys date: egen a1`var'_gbp=mean(`var') if currency!="gbp" & country!="WORL"
			bys date: egen a1`var'_eur=mean(`var') if currency!="eur" & country!="WORL"
			bys date: egen a1`var'_usd=mean(`var') if currency!="usd" & country!="WORL"
			bys date: egen a1`var'_jpy=mean(`var') if currency!="jpy" & country!="WORL"
			bys date: egen a1`var'_chf=mean(`var') if currency!="chf" & country!="WORL"
			bys date: egen a1`var'_oth=mean(`var') if currency!="oth" & country!="WORL"

			bys date: egen a2`var'_gbp=max(a1`var'_gbp) 
			bys date: egen a2`var'_eur=max(a1`var'_eur) 
			bys date: egen a2`var'_usd=max(a1`var'_usd) 
			bys date: egen a2`var'_jpy=max(a1`var'_jpy) 
			bys date: egen a2`var'_chf=max(a1`var'_chf) 
			bys date: egen a2`var'_oth=max(a1`var'_oth) 
			
			gen `var'_nk_m1=a2`var'_gbp
			replace `var'_nk_m1=a2`var'_eur if currency=="eur"
			replace `var'_nk_m1=a2`var'_usd if currency=="usd"
			replace `var'_nk_m1=a2`var'_jpy if currency=="jpy"
			replace `var'_nk_m1=a2`var'_chf if currency=="chf"
			replace `var'_nk_m1=a2`var'_oth if currency=="oth"
			}
			drop a1* a2*
			sort country currency date
		
		*Measure 2: Aggregate growth rate in other currencies to all countries  
			local sufix loan loan_f claims claims_f
			foreach var of local sufix{
			bys date: egen a1`var'_gbp=sum(`var') if currency=="gbp" & country!="WORL"
			bys date: egen a1`var'_eur=sum(`var') if currency=="eur" & country!="WORL"
			bys date: egen a1`var'_usd=sum(`var') if currency=="usd" & country!="WORL"
			bys date: egen a1`var'_jpy=sum(`var') if currency=="jpy" & country!="WORL"
			bys date: egen a1`var'_chf=sum(`var') if currency=="chf" & country!="WORL"
			bys date: egen a1`var'_oth=sum(`var') if currency=="oth" & country!="WORL"	
			bys date: egen a1`var'_total=sum(`var') if country!="WORL"	
			bys date: egen a2`var'_gbp=max(a1`var'_gbp) 
			bys date: egen a2`var'_eur=max(a1`var'_eur) 
			bys date: egen a2`var'_usd=max(a1`var'_eur) 
			bys date: egen a2`var'_jpy=max(a1`var'_jpy) 
			bys date: egen a2`var'_chf=max(a1`var'_chf) 
			bys date: egen a2`var'_oth=max(a1`var'_oth) 
			bys date: egen a2`var'_total=max(a1`var'_total) 
			}
			sort country currency date	
		
			*Compute total claims in "other currencies" at the bank-world level
				local sufix loan loan_f claims claims_f
				foreach var of local sufix{
				gen a3`var'_gbp=a2`var'_total-a2`var'_gbp 
				gen a3`var'_eur=a2`var'_total-a2`var'_eur
				gen a3`var'_usd=a2`var'_total-a2`var'_usd
				gen a3`var'_jpy=a2`var'_total-a2`var'_jpy
				gen a3`var'_chf=a2`var'_total-a2`var'_chf
				gen a3`var'_oth=a2`var'_total-a2`var'_oth
				
				gen DAx`var'_nk_m2=a3`var'_gbp
				replace DAx`var'_nk_m2=a3`var'_eur if currency=="eur"
				replace DAx`var'_nk_m2=a3`var'_usd if currency=="usd"
				replace DAx`var'_nk_m2=a3`var'_jpy if currency=="jpy"
				replace DAx`var'_nk_m2=a3`var'_chf if currency=="chf"
				replace DAx`var'_nk_m2=a3`var'_oth if currency=="oth"
				}
				
				drop a1* a2* a3*
			
			*Aggregate growth rates for "other currencies" at the bank-world level  
				xtset IDCM date
				sort IDCM date
				local Flows claims loan
				foreach var of local Flows {
				gen DA`var'1_nk_m2 = (ln(abs(L.DAx`var'_nk_m2)+DAx`var'_f_nk_m2)-ln(abs(L.DAx`var'_nk_m2)))
				}
				
				local Flows claims loan
				foreach var of local Flows {
				gen DA`var'2_nk_m2 = (DAx`var'_f_nk_m2/(abs(L.DAx`var'_nk_m2)))
				}
		
				sort country currency date
				
				rename claims AG_CSclaims
				rename loan AG_CSloan
				
				keep country currency date DA* AG_CSclaims AG_CSloan
				
				save AGPanel_Dgrowth.dta, replace 

/*

Compute RSF and other related variables

*/ 			

	*Load working sample
		cd "$dta_banks"
		use AGPanel_CCCL_02.dta, clear 	
		
	*Auxiliary variables
		
	*Generate identifier per bank/currency

		*Generate dummy=1 if country is Eurozone
		gen eurozone=1 if country=="ITAL" | country=="FRAN" | country=="NETH" | country=="RGER" | country=="BELG" | country=="CYPR" | country=="PORT" | ///
		country=="LUXE" | country=="MALT" | country=="FINL" | country=="LATV" | country=="SPAI" | country=="GREE" | country=="LITH" | ///
		country=="ESTO" | country=="SLOV" | country=="EIRE" | country=="SKRP" | country=="AUSR" 
		replace eurozone=0 if eurozone!=1
		
		*Create dummy=1 if bank is owned by Eurozone bank
		gen eurozoned=1 if countrycode2_nat=="ITAL" | countrycode2_nat=="FRAN" | countrycode2_nat=="NETH" | countrycode2_nat=="RGER" | countrycode2_nat=="BELG" | countrycode2_nat=="CYPR" | countrycode2_nat=="PORT" | ///
		countrycode2_nat=="LUXE" | countrycode2_nat=="MALT" | countrycode2_nat=="FINL" | countrycode2_nat=="LATV" | countrycode2_nat=="SPAI" | countrycode2_nat=="GREE" | countrycode2_nat=="LITH" | ///
		countrycode2_nat=="ESTO" | countrycode2_nat=="SLOV" | countrycode2_nat=="EIRE" | countrycode2_nat=="SKRP" | countrycode2_nat=="AUSR" 
		replace eurozoned=0 if eurozoned!=1
		
		*Create dummy=1 if bank is owned by bank within a foreign currency area 
		gen own_var=1 if countrycode2_nat=="USA" & currency=="usd"
		replace own_var=1 if eurozoned==1 & currency=="eur"
		replace own_var=1 if countrycode2_nat=="SWIT" & currency=="chf"
		replace own_var=1 if countrycode2_nat=="JAPA" & currency=="jpy"
		replace own_var=0 if own_var!=1
		
		*Create dummy=1 if bank is owned by a bank from a non-UK country 
		gen foreign=0 if countrycode2_nat=="UKIN"
		replace foreign=1 if foreign!=0
		
		*Create dummy=1 if bank is a foreign subsidiary and dummy=0 if is a foreign branch
		gen subown=1 if sub_or_branch=="S"
		replace subown=0 if sub_or_branch=="B"
		
		*Generate branch identifier
		gen branch=0
		replace branch=1 if subown==0
		
		*Branch identifier within subsample of foreign banks 
		gen braown=(subown-1)*-1
				
	*Ratio of BS FX funding from Abroad 
	
	*Ratio of FX liabilities from BT
		gen rnrliab_bt=nr_claim_ag/tasset_d1
		gen rnCSrliab1_bt=nr_liab_/CStasset_
		gen rnCSrliab2_bt=nr_liab_/tasset_d1
		
	*Compute aggregate liabilities from CL
		preserve
		keep if currency=="eur" | currency=="usd"
		drop if country=="WORL"
		bys IDB currency date: egen tCSliab_cl=sum(tliab)
		bys IDB date: egen tliab_cl=sum(tliab)
		collapse (mean) tCSliab_cl tliab_cl, by(IDB currency date)
		save liabcl_ags.dta, replace
		restore
		
		merge m:1 IDB currency date using liabcl_ag.dta 
		drop _merge
		sort bankname country currency date
		
	*Ratio of FX liabilities from CC
		gen rnrliab_cl=tliab_cl/tasset_d1
		gen rnCSrliab1_cl=tCSliab_cl/CStasset_
		gen rnCSrliab2_cl=tCSliab_cl/tasset_d1
		
	*Compute aggregate liabilities from CL
		preserve
		*replace liab_int=0 if liab_int<0
		keep if currency=="eur" | currency=="usd"
		drop if country=="WORL"
		bys IDB currency date: egen tCSint_cl=sum(liab_int)
		bys IDB date: egen tint_cl=sum(liab_int)
		collapse (mean) tCSint_cl tint_cl, by(IDB currency date)
		save intcl_ags.dta, replace
		restore
		
	*Compute aggregate liabilities from currency areas (CA)		
		preserve
		*replace liab_int=0 if liab_int<0
		keep if currency=="eur" | currency=="usd"
		keep if country=="USA" | eurozone==1
		bys IDB currency date: egen tCSint_ca=sum(liab_int)
		bys IDB date: egen tint_ca=sum(liab_int)
		collapse (mean) tCSint_ca tint_ca, by(IDB currency date)
		save intca_ags.dta, replace
		restore
		
		preserve
		keep if currency=="eur" | currency=="usd"
		keep if country=="USA" | eurozone==1
		bys IDB date: egen sum_usd=sum(liab_int) if currency=="usd" & country=="USA"
		bys IDB date: egen sum_eur=sum(liab_int) if currency=="eur" & eurozone==1
		replace sum_usd=sum_eur if currency=="eur"
		collapse (mean) sum_usd, by(IDB currency date)
		save intca_ag2s.dta, replace
		restore
		
		merge m:1 IDB currency date using intcl_ags.dta 
		drop _merge
		merge m:1 IDB currency date using intca_ags.dta 
		drop _merge
		merge m:1 IDB currency date using intca_ag2s.dta 
		drop _merge
		sort bankname country currency date

		*Ratio of FX liabilities from CL 
		replace liab_int=0 if liab_int<0
		gen rintliab_cl=tint_cl/nr_claim_ag
		gen rCSintliab1_cl=tCSint_cl/nr_liab_	
		gen rCSintliab2_cl=tCSint_cl/nr_claim_ag
		
		*Ratio of FX liabilities from CA 
		gen rintliab_ca=tint_ca/nr_claim_ag
		gen rCSintliab1_ca=tCSint_ca/nr_liab_	
		gen rCSintliab2_ca=tCSint_ca/nr_claim_ag
		
		*Ratio of FX liabilities from CA separate for usd and eur
		gen rCSbyk1_ca=sum_usd/nr_claim_ag
		gen rCSbyk2_ca=sum_usd/tasset_d1   

		*Dummies = 1 if internal channels are active
		foreach var of varlist rCSbyk1_ca rCSbyk2_ca rintliab_ca rCSintliab1_ca rCSintliab2_ca rintliab_cl rCSintliab1_cl rCSintliab2_cl{
		bys IDB: egen m`var'=max(`var')
		gen d`var'=1 if m`var'!=0
		replace d`var'=0 if d`var'==.
		}
		
		save AGPanel_drop1.dta, replace 

/*

Compute market-share weighted data on exposures + control variables

*/ 	
	
	*Load working sample
		cd "$dta_banks"
		use AGPanel_drop1.dta, clear 
		
	*merge ICM variables 
		*Merge internal variables 
		merge m:1 bankname currency date using intvar.dta
		*Note: Missmatches correspond to (a) other currencies and (b) obs. before 2007q4
		drop _merge
		sort bankname country currency date
		
	*Compute ICM ratios of interest 	
		gen rCStliab4=intgtliab/tasset_d1 
		gen rCStliab5=intgtbs_/tasset_d1

	*Compute aggregate claims per country-currency-date
		egen IDCM=group(country currency)
		bys IDCM date: egen tsclaims=sum(claims)
		bys IDCM date: egen tsloan=sum(loan)
		bys IDCM date: egen tsclaims_f=sum(claims_f)
		bys IDCM date: egen tsloan_f=sum(loan_f)
	
		preserve
		keep country currency date tsclaims tsloan tsclaims_f tsloan_f
		collapse (mean) tsclaims tsloan tsclaims_f tsloan_f, by(country currency date)
		sort country currency date
		save AGclaims_CCCL_02.dta, replace
		restore
	
	*Compute individual banks' market shares per country-currency-date
		gen ms_claims=claims/tsclaims
		gen ms_loan=loan/tsloan
	
	*Winsorize variables on market shares
		local winvarlist ms_claims ms_loan
		foreach var of local winvarlist{
		rename `var' dropx_`var'
		winsor dropx_`var', gen(`var') p(0.01)
		drop dropx_`var'
		}

	*Compute market-share weighted variables 
		local lista Exp_bt1 Exp_bt2 zExp_bt1 zExp_bt2 ///
		Dclaims1_nk_m1 Dloan1_nk_m1 Dclaims2_nk_m1 Dloan2_nk_m1 Dclaims1_nk_m2 Dloan1_nk_m2 Dclaims2_nk_m2 Dloan2_nk_m2 ///
		rdeps_ag rdept_ag rdepa_ag rdepnr_ag rdeprt_ag rdepuk_ag rdeps rdept rdepat rdepa /// 
		rdepnr rdeprt rdsight rcap_d1 rcap_d2 tcred_d1 tasset_d1 tasset_d2 ///
		ltasset_d1 ltasset_d2 rliq_d1 rliq_d2 rliq_d3 rliqCS1 rliqCS2 rliqCS3 rliqCS4 rliqCS5 rliqCS6 ///
		rCStliab4 rCStliab5 own_var braown foreign branch rCSbyk1_ca rCSbyk2_ca rintliab_ca rCSintliab1_ca rCSintliab2_ca rintliab_cl rCSintliab1_cl rCSintliab2_cl ///
		
		foreach var of local lista {
		gen msc_`var'=ms_claims*`var'
		gen msl_`var'=ms_loan*`var'
		}
	 	 		 
	*Collapse (sum) sample at the country-currency-date level 
		collapse (sum) msc_* msl_*, by(country currency date)
	
	*Merge total claims and loans 
		merge 1:1 country currency date using AGclaims_CCCL_02.dta
		drop _merge

	*Compute aggregate growth rates for LHS-variables 
		xtset IDCM date
		sort IDCM date
		local Flows tsclaims tsloan
		foreach var of local Flows {
		gen D`var'1 = (ln(abs(L.`var')+`var'_f)-ln(abs(L.`var')))
		}
		
		local Flows tsclaims tsloan
		foreach var of local Flows {
		gen D`var'2 = (`var'_f/(abs(L.`var')))
		}
	
		rename Dtsclaims1 Dclaims1
		rename Dtsclaims2 Dclaims2
		rename Dtsloan1 Dloan1
		rename Dtsloan2 Dloan2
			
	*Keep country-currency pairs from the main sample: Dclaims1 Dloan1 Dclaims2 Dloan2  
		merge m:1 country currency using AG_filter.dta
			
		save AGPanel_Xvars.dta, replace 
		
/*

Finalize sample, winsorize and merge auxiliary variables

*/ 	
	
	cd "$dta_banks"
	use AGPanel_Xvars.dta, clear //this data includes all variables of interest
	
	*Keep relevant observations
		keep if _merge==3
		drop _merge
		
	*Merge quarterly GDP measures generated in the Dofile "country_IMF.do".
		merge m:1 country date using series_gdpgbp.dta
		keep if _merge==3 
		xtset IDCM date
			
	*Compute growth rates scaled by countries' quarterly GDP 
		local Flows claims loan
		foreach var of local Flows {
		gen D`var'gdp1 = (ts`var'_f/(abs(L.qgdpgbp1)))
		gen D`var'gdp2 = (ts`var'_f/(abs(L.qgdpgbp2)))
		gen D`var'gdp3 = (ts`var'_f/(abs(L1qgdpgbp1)))
		gen D`var'gdp4 = (ts`var'_f/(abs(L1qgdpgbp2)))
		}
		sum Dclaimsgdp1 Dclaimsgdp2 Dclaimsgdp3 Dclaimsgdp4

	*Merge assets growth rates computed above
		drop _merge
		merge 1:1 country currency date using AGPanel_Dgrowth.dta
		keep if _merge==3 //these are observations matched with the bank-level regressions
		drop _merge
	
	*Generate global for exposures
		global rsflist msc_Exp_bt1 msc_Exp_bt2 msl_Exp_bt1 msl_Exp_bt2 msc_zExp_bt1 msc_zExp_bt2 msl_zExp_bt1 msl_zExp_bt2
		sum $rsflist
		
	*Merge data on CIP deviations 
		drop if currency=="gbp" | currency=="oth" 
		merge m:1 currency date using cb_sample1.dta
		drop _merge
		sort country currency date
	
	*Save sample including BoE-data
	cd "$dta_banks"
	save REG_T27_AG.dta, replace //this data includes the sample ready for regressions
			
/*

Compute BIS growth rates 

*/ 					
	
*Paste manually data from Excel in: FOLDER\Bisdata\bisdata_currency.xlx // Excel Sheet "bis_growth"
	cd "$dta_banks"
	*save BIS_growth_a1.dta, replace //this data includes the sample ready for regressions
	use BIS_growth_a1.dta, clear

*Replace string variables
	replace mix="flow" if mix=="F:FX and break adjusted change (BIS calculated)"
	replace mix="stock" if mix=="S:Amounts outstanding / Stocks"	
	replace currency="usd" if currency=="USD:US Dollar"	
	replace currency="eur" if currency=="EUR:Euro"	

*Reshape and create panel 
	reshape long date, i(mix currency country) j(claims) string  
	rename date xclaims
	rename claims dateaux
	rename xclaims claims
	
*Merge date variable
	merge m:1 dateaux using date_bisgrowth.dta
	drop _merge
	order dvar
		
*Extract date components
	gen year  = substr(dvar, 1, 4)
	gen quarter  = substr(dvar, 7, 1)
	destring year quarter, replace
		
*Generate date variable
	gen date = yq(year, quarter)
	format date %tqYY!qq
	order date year quarter
	drop dvar dateaux  
	order country currency mix date year quarter 
	sort country currency mix date year quarter 
		
*Merge ISO country-code as in BoE data
	gen code_2digit=iso_a2
	merge m:1 code_2digit using countrycode_all.dta
	
*Filter country sample as in regressions
	rename country countryname
	rename _merge mergeccode
	gen country=code_4digit
	merge m:1 country using AG_filtercountry.dta
	*drop if _merge==2 //these are 29 countries not used in the analysis and not reported by BIS
	*drop if _merge==1 //these are 20 countries (mostly islands and UK) not used in the analysis 
	keep if _merge==3
	keep if year>=2000
	gen country_code=iso_a2
	drop _merge
		
*Change data to from USD millions to GBP thousend
	gen gbpclaims=claims
	rename claims usdclaims
	merge m:1 date using exrate_data.dta
	drop _merge
	replace gbpclaims=gbpclaims*1000
	replace gbpclaims=gbpclaims*exrate

*Compute growth rates
	drop aux1
	bys country currency date: egen aux1=max(gbpclaims) if mix=="flow"
	bys country currency date: egen aux2=max(aux1) 
	drop if mix=="flow"
	rename aux2 gbpclaims_f
	drop aux1 mix
	
	egen idt=group(country currency)
	xtset idt date
	sort idt date
	
	local Flows gbpclaims
	foreach var of local Flows {
	gen D`var'1 = (ln(abs(L.`var')+`var'_f)-ln(abs(L.`var')))
	}
	
	local Flows gbpclaims
	foreach var of local Flows {
	gen D`var'2 = (`var'_f/(abs(L.`var')))
	}
	
*Compute same growth rate but scaled by GDP
	
	*Merge quarterly GDP measures generated in the Dofile "country_IMF.do".
		merge m:1 code_2digit date using series_gdpgbp.dta
		keep if _merge==3 
		egen IDCM=group(country currency)
		sort IDCM date
		xtset IDCM date	
	
	*Compute growth rates scaled by countries' quarterly GDP 
		local Flows gbpclaims
		foreach var of local Flows {
		gen D`var'gdp1 = (`var'_f/(abs(L.qgdpgbp1)))
		}
	
		gen bis_countryname=country
		
		keep code_2digit code_3digit code_4digit bis_countryname currency date Dgbp* Dgbpclaimsgdp1	
			
*Save for merging with BoE country-level panel
		save bis_growth.dta, replace             
			
/*

Compute BIS UK Exposure measures 

*/ 					
				
	*Load data imported from Excel
		use bis_sourcedata.dta, clear

	*Adjust variable names
		keep reportingcountry counterpartycountry currencydenomination date_*
		rename counterpartycountry country
		rename reportingcountry sourcecountry
		rename currencydenomination currency

	*Adjust variable components
		replace currency="eur" if currency=="EUR:Euro"
		replace currency="all" if currency=="TO1:All currencies"
		replace currency="usd" if currency=="USD:US Dollar"
		replace sourcecountry="world" if sourcecountry=="5A:All reporting countries"
		replace sourcecountry="uk" if sourcecountry=="GB:United Kingdom"
		gen iso_a2  = substr(country, 1, 2)
		order iso_a2
		drop country
		order sourcecountry iso_a2 currency 
		drop if _n>=962 //Adjust for missing variables added when copying data from Excel, otherwise drop!!!

	*Drop aggregate country groups (i.e. Latin America, EU, etc.)
		drop if iso_a2=="1C" | iso_a2=="1N" | iso_a2=="1W" | iso_a2=="1Z" | iso_a2=="2B" | iso_a2=="2D" | ///
		iso_a2=="2H" | iso_a2=="2N" | iso_a2=="2O" | iso_a2=="2R" | iso_a2=="2S" | iso_a2=="2T" | iso_a2=="2U" | ///
		iso_a2=="5J" | iso_a2=="5C" | iso_a2=="5K" | iso_a2=="5M" | iso_a2=="5R" | iso_a2=="4Y" | iso_a2=="4W" | /// 
		iso_a2=="4U" | iso_a2=="4T" | iso_a2=="4L" | iso_a2=="3C" | iso_a2=="2C" | iso_a2=="2W" 

	*Reshape panel 	
		reshape long date, i(sourcecountry iso_a2 currency) j(claims) string  
		rename claims dateaux
		rename date claims

	*Merge date variable
		merge m:1 dateaux using "FOLDER\Work Files\dateaux.dta"
		drop _merge
	
	*Extract date components
		gen year  = substr(daterare, 1, 4)
		gen quarter  = substr(daterare, 7, 1)
		destring year quarter, replace	
			
	*Generate date variable
		gen date = yq(year, quarter)
		format date %tqYY!qq
		order date year quarter
		drop dateaux daterare  
			
	*Change data to from USD millions to GBP thousend
		gen gbpclaims=claims
		rename claims usdclaims
		merge m:1 date using exrate_data.dta
		drop _merge
		replace gbpclaims=gbpclaims*1000
		replace gbpclaims=gbpclaims*exrate
		keep sourcecountry iso_a2 currency date gbpclaims		
		order sourcecountry iso_a2 currency date gbpclaims	

	*Merge 4-digit code
		gen code_2digit=iso_a2
		merge m:1 code_2digit using countrycode_all.dta
		
	*Filter country sample as in regressions
		rename country countryname
		rename _merge mergeccode
		gen country=code_4digit
		merge m:1 country using AG_filtercountry.dta
		*drop if _merge==2 //these are 29 countries not used in the analysis and not reported by BIS
		*drop if _merge==1 //these are 20 countries (mostly islands and UK) not used in the analysis 
		keep if _merge==3
		gen country_code=iso_a2
		drop _merge

	*Save sample
		save bis_Stocks.dta, replace	

	/*

	Generate sub-samples of BIS stocks as follows: 

	Auxiliary I. Total Claims vis-a-vis UK (all currencies)

	Auxiliary II. Total Claims vis-a-vis World (all currencies)
	 
	Auxiliary III. Claims vis-a-vis World (per currency)
	
	Auxiliary IV. Claims vis-a-vis UK (per currency, BoE)

	*/	
	
		*Auxiliary I
			use bis_Stocks.dta, clear
			keep if sourcecountry=="uk"
			keep if currency=="all"
			sort code_4digit date
			keep country code_2digit code_3digit code_4digit date gbpclaims		
			order country code_2digit code_3digit code_4digit date gbpclaims	
			rename gbpclaims ukclaims
			save bis_UKflows.dta, replace
	
		*Auxiliary II
			use bis_Stocks.dta, clear
			keep if sourcecountry=="world"
			keep if currency=="all"
			sort code_4digit date
			keep country code_2digit code_3digit code_4digit date gbpclaims		
			order country code_2digit code_3digit code_4digit date gbpclaims	
			rename gbpclaims worldclaims
			merge 1:1 country date using bis_UKflows.dta
			keep if _merge==3
			drop _merge
			gen ukratio1=ukclaims/worldclaims
			bys country: egen aux1=mean(ukratio1) if date<=quarterly("2008q1", "YQ") 
			bys country: egen ukratio2=max(aux1)
			bys country: egen aux2=mean(ukratio1) 
			bys country: egen ukratio3=max(aux2)
			drop aux*
			save bis_UKrat.dta, replace
		
		*Auxiliary III
			use bis_Stocks.dta, clear
			keep if sourcecountry=="world"
			drop if currency=="all"
			sort code_4digit date
			keep country currency code_2digit code_3digit code_4digit date gbpclaims		
			order country currency code_2digit code_3digit code_4digit date gbpclaims	
			rename gbpclaims CSbisclaims
			merge m:1 country date using bis_UKrat.dta
			keep if _merge==3
			drop _merge
			save bis_CSwld.dta, replace
	
		*Auxiliary IV
			cd "$dta_banks"
			use AGPanel_Dgrowth.dta, clear 
			
			*Compute aggregate claims from UK per country
				bys country date: egen ukclaims_boe1=sum(AG_CSclaims)	//claims
				bys country date: egen ukclaims_boe2=sum(AG_CSloan)	    //loans
				
			*Filter observations from bank sample
				merge m:1 country using AG_filtercountry.dta
				keep if _merge==3
				drop _merge

			*Keep relevant variables
				keep country currency date ukclaims_boe1 ukclaims_boe2 AG_CSclaims AG_CSloan
				keep if currency=="eur" | currency=="usd" 
				gen code_4digit=country
				drop country
				order code_4digit currency
				save boe_CSwld.dta, replace

	*Merge BIS data with aggregate BoE data to compute ratios 
		use bis_CSwld.dta, clear
		drop if date>quarterly("2016q1", "YQ") 
		drop if date<quarterly("2002q1", "YQ") 
		merge 1:m code_4digit currency date using boe_CSwld.dta
		drop _merge
		
	*Compute aggregate ratios using BoE Data
		gen aukratio4=ukclaims_boe1/worldclaims
		gen aukratio5=ukclaims_boe2/worldclaims
		bys country currency: egen aux1=mean(aukratio4) 
		bys country currency: egen ukratio4=max(aux1)
		bys country currency: egen aux2=mean(aukratio5)
		bys country currency: egen ukratio5=max(aux2)
		drop aux*
	
	*Compute currency-specific ratios using BoE Data 
		gen ukratio6=AG_CSclaims/worldclaims
		gen ukratio7=AG_CSloan/worldclaims
		bys country currency: egen aux1=mean(ukratio6)
		bys country currency: egen ukratio8=max(aux1)
		bys country currency: egen aux2=mean(ukratio7)  
		bys country currency: egen ukratio9=max(aux2)
		drop aux*
		keep code_2digit code_3digit code_4digit currency date ukratio*	aukratio* 
		sort code_2digit code_3digit code_4digit currency date 
		save bis_ukratio.dta, replace			
		
/*

Merge BIS data to BoE panel

*/	

	*Load BoE aggregated sample
		cd "$dta_banks"
		use REG_T27_AG.dta, clear 
	
	*Sample setup
		drop dup
		sort IDCM date
		by IDCM date: gen dup = cond(_N==1,0,_n)
		tab dup
		drop if dup==2
		egen IDM=group(currency)
		xtset IDCM date
		sort IDCM date		
	
	*Keep currencies of interest
		keep if currency=="eur" | currency=="usd"
		drop code_4digit
		gen code_4digit=country
	
	*Merge BIS ratios
		merge 1:1 code_4digit currency date using bis_ukratio.dta
		keep if _merge==3
		drop _merge
	
	*Merge BIS growth rates
		merge 1:1 code_4digit currency date using bis_growth.dta
		keep if _merge==3
		drop _merge
	
	*Merge BIS CS growth rates
		merge 1:1 code_2digit currency date using bisCSsample.dta
		keep if _merge==3
		drop _merge
		
	*Merge growth rates and ratios (new)
		merge 1:1 code_2digit currency date using CSBIS_all.dta
		keep if _merge==3
		drop _merge
		
	*Global for growth rates and ratios
		global bisgrowthvar Dreclaim1 Dreclaimgdp1 Dwclaim1 Drwclaim1 Dukclaim1 Dcaclaim1 Dwclaimgdp1 Drwclaimgdp1 Dukclaimgdp1 Dcaclaimgdp1 
		global bisratiovar ruka rukb rukCSa rukCSb avruka avrukb avrukCSa avrukCSb
		
	*Generate and merge sample split for UK funding reliance
		preserve
	
		*Compute mean ratio per country currency pair
			collapse (mean) msc_rCStliab4 msc_rCStliab5 msl_rCStliab4 msl_rCStliab5 msc_braown msl_braown msc_own_var msl_own_var msc_branch msl_branch aukratio4 aukratio5 ukratio1 ukratio2 ukratio3 ukratio4 ukratio5 ukratio6 ukratio7 ukratio8 ukratio9 $bisratiovar,  by(country currency)
		
		*Dummy=1 if ratio is above the median of all countries	
			local sufix msc_braown msl_braown msc_own_var msl_own_var msc_branch msl_branch aukratio4 aukratio5 ukratio1 ukratio2 ukratio3 ukratio4 ukratio5 ukratio6 ukratio7 ukratio8 ukratio9 $bisratiovar
			foreach var of local sufix{
			egen rex`var'=median(`var')
			gen d1`var'=0
			replace d1`var'=1 if `var'>rex`var' 
			}
			
		*Dummy=1 if ratio is above the percentile 75 of all countries		
			local sufix msc_rCStliab4 msc_rCStliab5 msl_rCStliab4 msl_rCStliab5 msc_braown msl_braown msc_own_var msl_own_var msc_branch msl_branch aukratio4 aukratio5 ukratio1 ukratio2 ukratio3 ukratio4 ukratio5 ukratio6 ukratio7 ukratio8 ukratio9 $bisratiovar
			foreach var of local sufix{
			egen `var'p75 = pctile(`var'), p(75)
			gen d1p`var'=0
			replace d1p`var'=1 if `var'>`var'p75
			}
				
			save DUMMY_T27_AG.dta, replace
		restore
			
		merge m:1 country currency using DUMMY_T27_AG.dta
		drop _merge
		
	*Winsorize
		foreach var of varlist Dreclaim1 Dreclaimgdp1 DitemCAgdp1 DitemCAgdp2 msc_Exp_bt1-tsloan_f Dclaims1-Dloan2 qgdpgbp1-L1qgdpgbp2 ///
		$bisgrowthvar $bisratiovar Dclaimsgdp1-DAloan2_nk_m2 ukratio1-Dgbpclaimsgdp1 {
		rename `var' dropx_`var'
		winsor dropx_`var', gen(`var') p(0.01)
		drop dropx_`var'
		}
		
	*Restrict country-currency pairs to main sample 
		merge m:1 country currency using AG_filterv2.dta
	
	*Save regressions sample
		xtset IDCM date
		sort IDCM date		
		gen constant=1
		save REG_T27_BIS.dta, replace	
			
/*

Table 5: Macroeconomic dimension – Substitution across UK banks
  
*/				
	
*Load regression sample 
	cd "$dta_banks"
	use REG_T27_BIS.dta, clear 	
	xtset IDCM date
	sort IDCM date	
	
	sort IDCM date 
    quietly by IDCM date :  gen dup2 = cond(_N==1,0,_n)
	tab dup2
	keep if dup2==0
		
*Column I - Within sample substitution 
	preserve
	local cred Dclaims1
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
	
	keep if date>=quarterly("2003q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
	L5.c.`exp'#L2.c.`cip' ///
	L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) /*msc_Dclaims1_nk_m1*/ , absorb(IDCM date) cluster(IDC date)
			
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 /*msc_Dclaims1_nk_m1*/) ctitle(`expa') replace
	
	gen IDsampleM=1 if e(sample)==1

	keep IDCM date IDsampleM
	save IDsampleM.dta, replace
	
	restore
	
	drop _merge
	merge 1:1 IDCM date using IDsampleM.dta
	xtset IDCM date
	sort IDCM date	
			
*Column II - Within sample substitution / Low share of branches 
	preserve
	local cred Dclaims1
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
	
	keep if d1pmsl_branch==0
					
	keep if date>=quarterly("2003q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
	L5.c.`exp'#L2.c.`cip' ///
	L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) if IDsampleM==1, absorb(IDCM date) cluster(IDC date)
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 /*msc_Dclaims1_nk_m1*/) ctitle(`expa') 
	
	restore
		
*Column III - Within sample substitution / High share of branches 
	preserve
	local cred Dclaims1
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
	
	keep if d1pmsl_branch==1
					
	keep if date>=quarterly("2003q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
	L5.c.`exp'#L2.c.`cip' ///
	L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) if IDsampleM==1, absorb(IDCM date) cluster(IDC date)
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 /*msc_Dclaims1_nk_m1*/) ctitle(`expa') 

	restore
	
*Column IV - Within sample substitution / Low share ICM
	preserve
	local cred Dclaims1
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
	
	keep if d1pmsc_rCStliab4==0
					
	keep if date>=quarterly("2008q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
	L5.c.`exp'#L2.c.`cip' ///
	L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) if IDsampleM==1, absorb(IDCM date) cluster(IDC date)
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 /*msc_Dclaims1_nk_m1*/) ctitle(`expa') 
	
	restore
	
*Column V - Within sample substitution / High share ICM
	preserve
	local cred Dclaims1
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
	
	keep if d1pmsc_rCStliab4==1
					
	keep if date>=quarterly("2008q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' ///
	L5.c.`exp'#L2.c.`cip' ///
	L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) if IDsampleM==1, absorb(IDCM date) cluster(IDC date)
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 /*msc_Dclaims1_nk_m1*/) ctitle(`expa') 
	
	restore
	
//******************** END OF TABLE ***********************//	



/*

Table 6: Macroeconomic dimension – Substitution across source countries
  
*/	

*Column I - Out-of-sample substitution / UK
	preserve
	
	local cred Dukclaim1 
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
							
	keep if date>=quarterly("2003q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) msc_Dclaims1_nk_m1 if IDsampleM==1, absorb(IDCM IDM#date) cluster(IDC date)
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ctitle(`expa') 
	
	restore	
	
*Column II - Out-of-sample substitution / Rest of World
	preserve
	
	local cred Drwclaim1 
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
							
	keep if date>=quarterly("2003q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) msc_Dclaims1_nk_m1 if IDsampleM==1, absorb(IDCM IDM#date) cluster(IDC date)
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ctitle(`expa') 
	
	restore	
	
*Column III - Out-of-sample substitution / Claims from relevant Currency Areas
	preserve
	
	local cred Dcaclaim1 
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
					
	keep if date>=quarterly("2003q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) msc_Dclaims1_nk_m1 if IDsampleM==1, absorb(IDCM IDM#date) cluster(IDC date)
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ctitle(`expa') 
	
	keep if IDsampleM==1
	egen ncountry=group(country)
	sum ncountry
	
	restore		

*Column IV - Out-of-sample substitution / Claims from relevant Currency Areas - Low share of UK 
	preserve
	
	local cred Dcaclaim1 
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
	
	keep if d1pavrukCSb==0
				
	keep if date>=quarterly("2003q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) msc_Dclaims1_nk_m1 if IDsampleM==1, absorb(IDCM IDM#date) cluster(IDC date) 
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ctitle(`expa') 
	
	restore
	
*Column IV - Out-of-sample substitution / Claims from relevant Currency Areas - High share of UK 
	preserve
	
	local cred Dcaclaim1 
	local exp msc_zExp_bt1
	local cip adcb_3m 
    local share msc_
	
	keep if d1pavrukCSb==1
				
	keep if date>=quarterly("2003q1", "YQ") 
	reghdfe `cred' L5.c.`exp'#L1.c.`cip' L5.c.`exp'#L2.c.`cip' L5.c.`exp'#L3.c.`cip' ///
	L5.c.`exp'#L4.c.`cip' L5.`exp' L1.c.`cip' L2.c.`cip' L3.c.`cip' L4.c.`cip' ///
	L1.(`share'ltasset_d1 `share'rdepa `share'rliq_d1 `share'rcap_d2) msc_Dclaims1_nk_m1 if IDsampleM==1, absorb(IDCM IDM#date) cluster(IDC date)
	
	test L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'=0
    g Test_F = r(F)
    g Test_P = r(p)
    lincom L5.c.`exp'#L1.c.`cip'+L5.c.`exp'#L2.c.`cip'+L5.c.`exp'#L3.c.`cip'+L5.c.`exp'#L4.c.`cip'
    g Test_C = r(estimate)
	g Test_SD = r(se)
	
	outreg2 using AGtabA.xls, keep(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ///
	dec(3) addstat(Joint Coef., sum(Test_C), SD, sum(Test_SD), P-value, sum(Test_P), F-test, sum(Test_F)) addtext(Credit, `credit', Exposure, `expa', CIP, `cip')  ///
	sortvar(L5.`exp' L1.`share'ltasset_d1 L1.`share'rdepa L1.`share'rliq_d1 L1.`share'rcap_d2 msc_Dclaims1_nk_m1) ctitle(`expa') 
	
//******************** END OF TABLE ***********************//	

		
//******************** END OF DOFILE ***********************//	


	